from typing import Any

from . import base

class MockConnection(base.Connectable):
    def __init__(self, dialect, execute) -> None: ...
    engine: Any
    dialect: Any
    name: Any
    def schema_for_object(self, obj): ...
    def connect(self, **kwargs): ...
    def execution_options(self, **kw): ...
    def compiler(self, statement, parameters, **kwargs): ...
    def create(self, entity, **kwargs) -> None: ...
    def drop(self, entity, **kwargs) -> None: ...
    def execute(self, object_, *multiparams, **params) -> None: ...

def create_mock_engine(url, executor, **kw): ...
