from ...exc import InvalidRequestError

class AsyncMethodRequired(InvalidRequestError): ...
class AsyncContextNotStarted(InvalidRequestError): ...
class AsyncContextAlreadyStarted(InvalidRequestError): ...
