from typing import Any

def Serializer(*args, **kw): ...
def Deserializer(file, metadata: Any | None = ..., scoped_session: Any | None = ..., engine: Any | None = ...): ...
def dumps(obj, protocol=...): ...
def loads(data, metadata: Any | None = ..., scoped_session: Any | None = ..., engine: Any | None = ...): ...
