from ...engine import events as engine_event
from ...orm import events as orm_event

class AsyncConnectionEvents(engine_event.ConnectionEvents): ...
class AsyncSessionEvents(orm_event.SessionEvents): ...
