def add_fixture(fn, fixture) -> None: ...
def scan_for_fixtures_to_use_for_class(item) -> None: ...
def run_class_fixture_setup(request) -> None: ...
def run_class_fixture_teardown(request) -> None: ...
def run_fn_fixture_setup(request) -> None: ...
def run_fn_fixture_teardown(request) -> None: ...
